@@ -1,30 +1,30 @@
 <?php
 /**
- * ownCloud
- *
- * @author Arthur Schiwon
- * @copyright 2014 Arthur Schiwon blizzz@owncloud.com
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
- *
- * You should have received a copy of the GNU Affero General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+* ownCloud
+*
+* @author Arthur Schiwon
+* @copyright 2014 Arthur Schiwon blizzz@owncloud.com
+*
+* This library is free software; you can redistribute it and/or
+* modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
+* License as published by the Free Software Foundation; either
+* version 3 of the License, or any later version.
+*
+* This library is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU AFFERO GENERAL PUBLIC LICENSE for more details.
+*
+* You should have received a copy of the GNU Affero General Public
+* License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+*
+*/
 
 namespace OCA\user_ldap\tests;
 
 use OCA\user_ldap\lib\user\Manager;
 
-class Test_User_Manager extends \PHPUnit_Framework_TestCase {
+class Test_User_Manager extends \Test\TestCase {
 
 	private function getTestInstances() {
 		$access = $this->getMock('\OCA\user_ldap\lib\user\IUserTools');
@@ -33,12 +33,13 @@ class Test_User_Manager extends \PHPUnit_Framework_TestCase {
 		$log = $this->getMock('\OCA\user_ldap\lib\LogWrapper');
 		$avaMgr = $this->getMock('\OCP\IAvatarManager');
 		$image = $this->getMock('\OCP\Image');
+		$dbc = $this->getMock('\OCP\IDBConnection');
 
-		return array($access, $config, $filesys, $image, $log, $avaMgr);
+		return array($access, $config, $filesys, $image, $log, $avaMgr, $dbc);
 	}
 
 	public function testGetByDNExisting() {
-		list($access, $config, $filesys, $image, $log, $avaMgr) =
+		list($access, $config, $filesys, $image, $log, $avaMgr, $dbc) =
 			$this->getTestInstances();
 
 		$inputDN = 'cn=foo,dc=foobar,dc=bar';
@@ -57,7 +58,7 @@ class Test_User_Manager extends \PHPUnit_Framework_TestCase {
 		$access->expects($this->never())
 			->method('username2dn');
 
-		$manager = new Manager($config, $filesys, $log, $avaMgr, $image);
+		$manager = new Manager($config, $filesys, $log, $avaMgr, $image, $dbc);
 		$manager->setLdapAccess($access);
 		$user = $manager->get($inputDN);
 
@@ -69,7 +70,7 @@ class Test_User_Manager extends \PHPUnit_Framework_TestCase {
 	}
 
 	public function testGetByEDirectoryDN() {
-		list($access, $config, $filesys, $image, $log, $avaMgr) =
+		list($access, $config, $filesys, $image, $log, $avaMgr, $dbc) =
 			$this->getTestInstances();
 
 		$inputDN = 'uid=foo,o=foobar,c=bar';
@@ -88,7 +89,7 @@ class Test_User_Manager extends \PHPUnit_Framework_TestCase {
 		$access->expects($this->never())
 			->method('username2dn');
 
-		$manager = new Manager($config, $filesys, $log, $avaMgr, $image);
+		$manager = new Manager($config, $filesys, $log, $avaMgr, $image, $dbc);
 		$manager->setLdapAccess($access);
 		$user = $manager->get($inputDN);
 
@@ -96,7 +97,7 @@ class Test_User_Manager extends \PHPUnit_Framework_TestCase {
 	}
 
 	public function testGetByExoticDN() {
-		list($access, $config, $filesys, $image, $log, $avaMgr) =
+		list($access, $config, $filesys, $image, $log, $avaMgr, $dbc) =
 			$this->getTestInstances();
 
 		$inputDN = 'ab=cde,f=ghei,mno=pq';
@@ -115,7 +116,7 @@ class Test_User_Manager extends \PHPUnit_Framework_TestCase {
 		$access->expects($this->never())
 			->method('username2dn');
 
-		$manager = new Manager($config, $filesys, $log, $avaMgr, $image);
+		$manager = new Manager($config, $filesys, $log, $avaMgr, $image, $dbc);
 		$manager->setLdapAccess($access);
 		$user = $manager->get($inputDN);
 
@@ -123,7 +124,7 @@ class Test_User_Manager extends \PHPUnit_Framework_TestCase {
 	}
 
 	public function testGetByDNNotExisting() {
-		list($access, $config, $filesys, $image, $log, $avaMgr) =
+		list($access, $config, $filesys, $image, $log, $avaMgr, $dbc) =
 			$this->getTestInstances();
 
 		$inputDN = 'cn=gone,dc=foobar,dc=bar';
@@ -143,13 +144,15 @@ class Test_User_Manager extends \PHPUnit_Framework_TestCase {
 			->with($this->equalTo($inputDN))
 			->will($this->returnValue(false));
 
-		$manager = new Manager($config, $filesys, $log, $avaMgr, $image);
+		$manager = new Manager($config, $filesys, $log, $avaMgr, $image, $dbc);
 		$manager->setLdapAccess($access);
 		$user = $manager->get($inputDN);
+
+		$this->assertNull($user);
 	}
 
 	public function testGetByUidExisting() {
-		list($access, $config, $filesys, $image, $log, $avaMgr) =
+		list($access, $config, $filesys, $image, $log, $avaMgr, $dbc) =
 			$this->getTestInstances();
 
 		$dn = 'cn=foo,dc=foobar,dc=bar';
@@ -168,7 +171,7 @@ class Test_User_Manager extends \PHPUnit_Framework_TestCase {
 			->with($this->equalTo($uid))
 			->will($this->returnValue(false));
 
-		$manager = new Manager($config, $filesys, $log, $avaMgr, $image);
+		$manager = new Manager($config, $filesys, $log, $avaMgr, $image, $dbc);
 		$manager->setLdapAccess($access);
 		$user = $manager->get($uid);
 
@@ -180,7 +183,7 @@ class Test_User_Manager extends \PHPUnit_Framework_TestCase {
 	}
 
 	public function testGetByUidNotExisting() {
-		list($access, $config, $filesys, $image, $log, $avaMgr) =
+		list($access, $config, $filesys, $image, $log, $avaMgr, $dbc) =
 			$this->getTestInstances();
 
 		$dn = 'cn=foo,dc=foobar,dc=bar';
@@ -194,9 +197,11 @@ class Test_User_Manager extends \PHPUnit_Framework_TestCase {
 			->with($this->equalTo($uid))
 			->will($this->returnValue(false));
 
-		$manager = new Manager($config, $filesys, $log, $avaMgr, $image);
+		$manager = new Manager($config, $filesys, $log, $avaMgr, $image, $dbc);
 		$manager->setLdapAccess($access);
 		$user = $manager->get($uid);
+
+		$this->assertNull($user);
 	}
 
 }
