@@ -21,6 +21,14 @@
 *
 */
 
+// Show warning if a PHP version below 5.4.0 is used, this has to happen here
+// because base.php will already use 5.4 syntax.
+if (version_compare(PHP_VERSION, '5.4.0') === -1) {
+	echo 'This version of ownCloud requires at least PHP 5.4.0<br/>';
+	echo 'You are currently running ' . PHP_VERSION . '. Please update your PHP version.';
+	return;
+}
+
 // Show warning if PHP 7 is used as ownCloud is not compatible with PHP 7 until
 // version 8.2.0.
 if (version_compare(PHP_VERSION, '7.0.0') !== -1) {
@@ -41,6 +49,9 @@ try {
 	//show the user a detailed error page
 	OC_Response::setStatus(OC_Response::STATUS_SERVICE_UNAVAILABLE);
 	OC_Template::printExceptionErrorPage($ex);
+} catch (\OC\HintException $ex) {
+	OC_Response::setStatus(OC_Response::STATUS_SERVICE_UNAVAILABLE);
+	OC_Template::printErrorPage($ex->getMessage(), $ex->getHint());
 } catch (Exception $ex) {
 	\OCP\Util::logException('index', $ex);
 
