@@ -37,6 +37,7 @@ class Server extends SimpleContainer implements IServerContainer {
 	 * @param string $webRoot
 	 */
 	function __construct($webRoot) {
+		parent::__construct();
 		$this->webRoot = $webRoot;
 
 		$this->registerService('ContactsManager', function ($c) {
@@ -122,6 +123,8 @@ class Server extends SimpleContainer implements IServerContainer {
 			});
 			$groupManager->listen('\OC\Group', 'postAddUser', function (\OC\Group\Group $group, \OC\User\User $user) {
 				\OC_Hook::emit('OC_Group', 'post_addToGroup', array('uid' => $user->getUID(), 'gid' => $group->getGID()));
+				//Minimal fix to keep it backward compatible TODO: clean up all the GroupManager hooks
+				\OC_Hook::emit('OC_User', 'post_addToGroup', array('uid' => $user->getUID(), 'gid' => $group->getGID()));
 			});
 			return $groupManager;
 		});
@@ -634,7 +637,7 @@ class Server extends SimpleContainer implements IServerContainer {
 	 * Get the certificate manager for the user
 	 *
 	 * @param string $uid (optional) if not specified the current loggedin user is used
-	 * @return \OCP\ICertificateManager
+	 * @return \OCP\ICertificateManager | null if $uid is null and no user is logged in
 	 */
 	function getCertificateManager($uid = null) {
 		if (is_null($uid)) {
